# New in 0.15.3 (2022-03-24)

## Changes

## Bug fixes

-   Raise `NotImplementedError` when `categorical_covariate_keys` are used with {meth}`scvi.model.SCANVI.load_query_data`. ([#1458]).
-   Fix behavior when `continuous_covariate_keys` are used with {meth}`scvi.model.SCANVI.classify`. ([#1458]).
-   Unlabeled category values are automatically populated when {meth}`scvi.model.SCANVI.load_query_data` run on `adata_target` missing labels column. ([#1458]).
-   Fix dataframe rendering in dark mode docs ([#1448])
-   Fix variance constraint in {class}`~scvi.model.AmortizedLDA` that set an artifical bound on latent topic variance ([#1445]).
-   Fix {meth}`scvi.model.base.ArchesMixin.prepare_query_data` to work cross device (e.g., model trained on cuda but method used on cpu; see [#1451]).

## Contributors

-   [@jjhong922]
-   [@adamgayoso]

[#1451]: https://github.com/YosefLab/scvi-tools/pull/1451
[#1445]: https://github.com/YosefLab/scvi-tools/pull/1445
[#1448]: https://github.com/YosefLab/scvi-tools/pull/1448
[#1458]: https://github.com/YosefLab/scvi-tools/pull/1458
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
